import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

SHOPPING = "#00c1ff"


def user_orders_frame(parent, switch_func, API_URL, token):
    """
    A two-column user orders page that displays the products the user has purchased
    along with associated shop details. The layout and color scheme match your dashboard.
    """

    # Main container frame with transparent background
    frame = ctk.CTkFrame(parent, fg_color="transparent")

    # ----------------- TOP BAR -----------------
    top_bar = ctk.CTkFrame(frame, fg_color=SHOPPING, height=40)
    top_bar.pack(fill="x", side="top")

    top_label = ctk.CTkLabel(
        top_bar, text="My Orders", text_color="white", font=("Helvetica", 16, "bold")
    )
    top_label.pack(side="left", padx=20)

    def go_back():
        switch_func("dashboard")

    back_button = ctk.CTkButton(
        top_bar,
        text="Back",
        fg_color="white",
        text_color="black",
        command=go_back,
        width=60,
        height=30,
    )
    back_button.pack(side="right", padx=20, pady=5)

    # ----------------- MAIN SECTION (Sidebar + Content) -----------------
    main_section = ctk.CTkFrame(frame, fg_color="transparent")
    main_section.pack(fill="both", expand=True)

    # ----------------- LEFT SIDEBAR -----------------
    sidebar_frame = ctk.CTkFrame(main_section, width=200, fg_color="#2b2b2b")
    sidebar_frame.pack(side="left", fill="y")

    sidebar_title = ctk.CTkLabel(
        sidebar_frame, text="Menu", font=("Helvetica", 14, "bold"), text_color="white"
    )
    sidebar_title.pack(pady=(10, 5))

    def open_profile():
        switch_func("user_details")

    nav_dashboard = ctk.CTkButton(
        sidebar_frame,
        text="Dashboard",
        fg_color="#2b2b2b",
        text_color="white",
        hover_color="#3b3b3b",
        command=go_back,
    )
    nav_dashboard.pack(fill="x", padx=10, pady=5)

    nav_profile = ctk.CTkButton(
        sidebar_frame,
        text="My Profile",
        fg_color="#2b2b2b",
        text_color="white",
        hover_color="#3b3b3b",
        command=open_profile,
    )
    nav_profile.pack(fill="x", padx=10, pady=5)

    nav_orders = ctk.CTkButton(
        sidebar_frame,
        text="My Orders",
        fg_color="#3b3b3b",  # Active/selected state
        text_color="white",
        hover_color="#3b3b3b",
        state="disabled",
    )
    nav_orders.pack(fill="x", padx=10, pady=5)

    # ----------------- RIGHT CONTENT (Orders List) -----------------
    content_frame = ctk.CTkFrame(main_section, fg_color="transparent")
    content_frame.pack(side="left", fill="both", expand=True, padx=20, pady=20)

    main_title_label = ctk.CTkLabel(
        content_frame,
        text="Your Orders",
        font=("Helvetica", 18, "bold"),
        text_color="white",
    )
    main_title_label.pack(anchor="w", pady=(0, 5))

    subtitle_label = ctk.CTkLabel(
        content_frame,
        text="Review the products you have purchased.",
        font=("Helvetica", 12),
        text_color="#cccccc",
    )
    subtitle_label.pack(anchor="w", pady=(0, 15))

    # A frame to hold the list of orders
    orders_list_frame = ctk.CTkFrame(content_frame, fg_color="transparent")
    orders_list_frame.pack(fill="both", expand=True)

    # ----------- Functions to fetch and display orders -----------
    def fetch_orders():
        """
        Fetch the list of user orders from the API.
        """
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.get(f"{API_URL}/orders/list", headers=headers)
            if resp.status_code == 200:
                orders = resp.json()  # Expect a list of order dicts
                display_orders(orders, orders_list_frame)
            else:
                messagebox.showerror("Error", "Failed to fetch orders.")
        except Exception as ex:
            messagebox.showerror("Error", f"Request error: {ex}")

    def display_orders(orders, container):
        """
        Display each order with product and shop details.
        """
        # Clear previous content
        for widget in container.winfo_children():
            widget.destroy()

        if not orders:
            ctk.CTkLabel(container, text="No orders found.", text_color="white").pack(
                pady=10
            )
            return

        for order in orders:
            # Assume each order dict includes a 'product' dict and an 'order_date'
            product = order.get("product", {})
            order_date = order.get("order_date", "Unknown Date")

            order_frame = ctk.CTkFrame(container, corner_radius=5, fg_color="#2b2b2b")
            order_frame.pack(fill="x", padx=5, pady=5)

            # Left: Product image
            image_label = ctk.CTkLabel(order_frame, text="")
            image_label.pack(side="left", padx=5, pady=5)
            if product.get("images"):
                try:
                    img_url = product["images"][0]["image_url"]
                    img_resp = requests.get(img_url)
                    if img_resp.status_code == 200:
                        pil_img = Image.open(io.BytesIO(img_resp.content)).resize(
                            (60, 60)
                        )
                        tk_img = ImageTk.PhotoImage(pil_img)
                        image_label.configure(image=tk_img, text="")
                        image_label.image = tk_img
                except Exception as ex:
                    print(f"Product image error: {ex}")

            # Right: Order details and shop info
            info_frame = ctk.CTkFrame(order_frame, fg_color="transparent")
            info_frame.pack(side="left", fill="both", expand=True, padx=10)

            # Product Name
            ctk.CTkLabel(
                info_frame,
                text=product.get("name", "No Name"),
                font=("Helvetica", 13, "bold"),
                text_color="white",
            ).pack(anchor="w")

            # Price (and order date)
            price = product.get("price", 0.0)
            ctk.CTkLabel(
                info_frame, text=f"Price: {price:.2f}", text_color="#cccccc"
            ).pack(anchor="w")
            ctk.CTkLabel(
                info_frame, text=f"Ordered on: {order_date}", text_color="#cccccc"
            ).pack(anchor="w")

            # Shop Name
            shop_id = product.get("shop_id")
            shop_name_label = ctk.CTkLabel(
                info_frame, text="Shop: Loading...", text_color="#cccccc"
            )
            shop_name_label.pack(anchor="w")

            def fetch_shop_and_update_label(sid, label_widget):
                headers = {"Authorization": f"Bearer {token}"}
                try:
                    sresp = requests.get(f"{API_URL}/shop/get/{sid}", headers=headers)
                    if sresp.status_code == 200:
                        shop_data = sresp.json()
                        label_widget.configure(
                            text=f"Shop: {shop_data.get('name', 'No Shop Name')}"
                        )
                    else:
                        label_widget.configure(text="Shop: Not found")
                except Exception:
                    label_widget.configure(text="Shop: Error fetching")

            fetch_shop_and_update_label(shop_id, shop_name_label)

            # "View Order" button (placeholder action)
            def view_order():
                messagebox.showinfo(
                    "Order Details", f"View details for order of {product.get('name')}"
                )

            view_button = ctk.CTkButton(
                info_frame,
                text="View Order",
                fg_color=SHOPPING,
                text_color="white",
                command=view_order,
            )
            view_button.pack(anchor="e", pady=(5, 0))

    # Fetch orders when the frame loads
    fetch_orders()

    return frame
